"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.dataSourceConfig = exports.config = void 0;
const model_1 = require("./database/model");
const process_1 = require("process");
function die(reason) {
    console.error(reason);
    (0, process_1.exit)(1);
}
function initializeAppConfiguration() {
    const PORT = parseInt(process.env.PORT ?? '3001');
    const DEFAULT_BASE_URL = 'http://localhost:' + PORT;
    return {
        PORT: PORT,
        NODE_ENV: process.env.NODE_ENV ?? 'development',
        BASE_URL: process.env.BASE_URL ?? DEFAULT_BASE_URL,
        SECURITY_ISSUER: process.env.SECURITY_ISSUER ??
            die('the environment variable SECURITY_ISSUER is not defined!'),
        SECURITY_AUDIENCE: process.env.SECURITY_AUDIENCE ??
            die('the environment variable SECURITY_AUDIENCE is not defined!'),
        API_TOKEN: process.env.API_TOKEN ?? '',
    };
}
exports.config = initializeAppConfiguration();
exports.dataSourceConfig = {
    type: 'sqlite',
    database: 'db/device.db',
    synchronize: true,
    entities: [
        model_1.DeviceOverviewModel,
        model_1.ConcreteDeviceModel,
        model_1.InstantiableDeviceOverviewModel,
        model_1.InstantiableCloudDeviceModel,
        model_1.InstantiableBrowserDeviceModel,
        model_1.DeviceGroupModel,
        model_1.PeerconnectionModel,
    ],
};
//# sourceMappingURL=config.js.map