"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deviceGroupRepository = exports.DeviceGroupRepository = void 0;
const globals_1 = require("../../../globals");
const model_1 = require("../../model");
const deviceOverview_1 = require("./deviceOverview");
const service_common_1 = require("@crosslab/service-common");
class DeviceGroupRepository extends service_common_1.AbstractRepository {
    constructor() {
        super('Device Group');
    }
    initialize(AppDataSource) {
        this.repository = AppDataSource.getRepository(model_1.DeviceGroupModel);
    }
    async create(data) {
        const model = await super.create(data);
        model.type = 'group';
        return model;
    }
    async write(model, data) {
        await deviceOverview_1.deviceOverviewRepository.write(model, data);
        if (data.devices)
            model.devices = data.devices;
    }
    async format(model, flatGroup) {
        const devices = await this.resolveDeviceReferences(model.devices, flatGroup);
        return {
            ...(await deviceOverview_1.deviceOverviewRepository.format(model)),
            type: 'group',
            devices: devices.filter((value, index, array) => array.findIndex((device) => device.url === value.url) === index),
        };
    }
    async resolveDeviceReferences(deviceReferences, flatGroup) {
        const devices = [];
        for (const deviceReference of deviceReferences) {
            const device = await this.resolveDeviceReference(deviceReference, flatGroup);
            if (!device)
                continue;
            if (device.type === 'group' && flatGroup) {
                devices.push(...(await this.resolveDeviceReferences(device.devices)));
            }
            else {
                devices.push(device);
            }
        }
        return devices;
    }
    async resolveDeviceReference(deviceReference, flatGroup) {
        try {
            return await globals_1.apiClient.getDevice(deviceReference.url, {
                flat_group: flatGroup,
            });
        }
        catch (error) {
            console.error(error);
        }
        return undefined;
    }
}
exports.DeviceGroupRepository = DeviceGroupRepository;
exports.deviceGroupRepository = new DeviceGroupRepository();
//# sourceMappingURL=deviceGroup.js.map