"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.peerconnectionRepository = exports.PeerconnectionRepository = void 0;
const urlFromId_1 = require("../../methods/urlFromId");
const model_1 = require("../model");
const service_common_1 = require("@crosslab/service-common");
class PeerconnectionRepository extends service_common_1.AbstractRepository {
    constructor() {
        super('Peerconnection');
    }
    initialize(AppDataSource) {
        this.repository = AppDataSource.getRepository(model_1.PeerconnectionModel);
    }
    async create(data) {
        const model = await super.create(data);
        model.status = 'new';
        return model;
    }
    async write(model, data) {
        if (data.type)
            model.type = data.type;
        if (data.devices && data.devices.length !== 2) {
            throw new service_common_1.InvalidValueError(`Peerconnections need exactly 2 devices, received ${data.devices?.length}`, 400);
        }
        if (data.devices) {
            const deviceA = data.devices[0];
            const deviceB = data.devices[1];
            if (!deviceA.url || !deviceB.url) {
                throw new service_common_1.InvalidValueError('One of the provided devices does not have a url', 400);
            }
            model.deviceA = { ...deviceA, status: 'new' };
            model.deviceB = { ...deviceB, status: 'new' };
        }
    }
    async format(model) {
        return {
            url: (0, urlFromId_1.peerconnectionUrlFromId)(model.uuid),
            type: model.type,
            status: model.status,
            devices: [{ ...model.deviceA }, { ...model.deviceB }],
        };
    }
    formatOverview(model) {
        return {
            url: (0, urlFromId_1.peerconnectionUrlFromId)(model.uuid),
            type: model.type,
            status: model.status,
            devices: [{ url: model.deviceA.url }, { url: model.deviceB.url }],
        };
    }
}
exports.PeerconnectionRepository = PeerconnectionRepository;
exports.peerconnectionRepository = new PeerconnectionRepository();
//# sourceMappingURL=peerconnection.js.map