#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("./config");
const dataSource_1 = require("./database/dataSource");
const index_1 = require("./generated/index");
const globals_1 = require("./globals");
const callbacks_1 = require("./operations/callbacks");
const devices_1 = require("./operations/devices");
const service_common_1 = require("@crosslab/service-common");
const ws_1 = __importDefault(require("ws"));
async function startDeviceService() {
    await dataSource_1.AppDataSource.initialize(config_1.dataSourceConfig);
    globals_1.apiClient.accessToken = config_1.config.API_TOKEN;
    index_1.app.use((req, _res, next) => {
        for (const param in req.query) {
            if (typeof req.query[param] === 'string') {
                if (req.query[param] === 'true') {
                    ;
                    req.query[param] = true;
                }
                else if (req.query[param] === 'false') {
                    ;
                    req.query[param] = false;
                }
                else if (req.query[param] === 'undefined') {
                    ;
                    req.query[param] = undefined;
                }
            }
        }
        next();
    });
    index_1.app.get('/device/status', (_req, res) => {
        res.send({ status: 'ok' });
    });
    index_1.app.initService({
        security: {
            JWT: (0, service_common_1.JWTVerify)(config_1.config),
        },
        additionalHandlers: [callbacks_1.callbackHandling],
    });
    const wsServer = new ws_1.default.Server({ noServer: true });
    index_1.app.wsListeners = new Map();
    index_1.app.ws = (path, listener) => index_1.app.wsListeners.set(path, listener);
    (0, devices_1.websocketHandling)(index_1.app);
    const server = index_1.app.listen(config_1.config.PORT);
    server.on('upgrade', async (request, socket, head) => {
        const listener = index_1.app.wsListeners.get(request.url ?? '');
        if (listener) {
            wsServer.handleUpgrade(request, socket, head, (socket) => listener(socket));
        }
    });
    console.log('Device Service started successfully');
}
/* istanbul ignore if */
if (require.main === module) {
    startDeviceService();
}
//# sourceMappingURL=index.js.map