"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sendStatusChangedCallback = exports.sendClosedCallback = exports.sendChangedCallback = exports.statusChangedCallbacks = exports.closedCallbacks = exports.changedCallbacks = exports.callbackUrl = void 0;
const config_1 = require("../config");
const device_1 = require("../database/repositories/device");
const peerconnection_1 = require("../database/repositories/peerconnection");
const urlFromId_1 = require("./urlFromId");
const node_fetch_1 = __importDefault(require("node-fetch"));
exports.callbackUrl = (config_1.config.BASE_URL + '/callbacks/device').replace('//callbacks', '/callbacks');
exports.changedCallbacks = new Map();
exports.closedCallbacks = new Map();
exports.statusChangedCallbacks = new Map();
/**
 * This function sends a 'device-changed' callback.
 * @param device The device for which to send the callback.
 */
async function sendChangedCallback(device) {
    const urls = exports.changedCallbacks.get(device.uuid) ?? [];
    for (const url of urls) {
        console.log(`Sending changed-callback for device '${(0, urlFromId_1.deviceUrlFromId)(device.uuid)}' to '${url}'`);
        // TODO: proper error handling
        try {
            const res = await (0, node_fetch_1.default)(url, {
                method: 'POST',
                body: JSON.stringify({
                    callbackType: 'event',
                    eventType: 'device-changed',
                    device: await device_1.deviceRepository.format(device),
                }),
                headers: [['Content-Type', 'application/json']],
            });
            if (res.status === 410) {
                const changedCallbackURLs = exports.changedCallbacks.get(device.uuid);
                exports.changedCallbacks.set(device.uuid, changedCallbackURLs?.filter((cb_url) => cb_url != url));
            }
        }
        catch (error) {
            console.error(error);
        }
    }
}
exports.sendChangedCallback = sendChangedCallback;
/**
 * This function sends a 'peerconnection-closed' callback.
 * @param peerconnection The peerconnection for which to send the callback.
 */
async function sendClosedCallback(peerconnection) {
    const urls = exports.closedCallbacks.get(peerconnection.uuid) ?? [];
    for (const url of urls) {
        console.log(`Sending closed-callback for peerconnection '${(0, urlFromId_1.peerconnectionUrlFromId)(peerconnection.uuid)}' to '${url}'`);
        // TODO: proper error handling
        try {
            const res = await (0, node_fetch_1.default)(url, {
                method: 'POST',
                body: JSON.stringify({
                    callbackType: 'event',
                    eventType: 'peerconnection-closed',
                    peerconnection: await peerconnection_1.peerconnectionRepository.format(peerconnection),
                }),
                headers: [['Content-Type', 'application/json']],
            });
            if (res.status === 410) {
                const closedCallbackURLs = exports.closedCallbacks.get(peerconnection.uuid);
                exports.closedCallbacks.set(peerconnection.uuid, closedCallbackURLs?.filter((cb_url) => cb_url != url));
            }
        }
        catch (error) {
            console.error(error);
        }
    }
}
exports.sendClosedCallback = sendClosedCallback;
/**
 * This function sends a 'peerconnection-status-changed' callback.
 * @param peerconnection The peerconnection for which to send the callback.
 */
async function sendStatusChangedCallback(peerconnection) {
    const urls = exports.statusChangedCallbacks.get(peerconnection.uuid) ?? [];
    for (const url of urls) {
        console.log(`Sending status-changed-callback for peerconnection '${(0, urlFromId_1.peerconnectionUrlFromId)(peerconnection.uuid)}' to '${url}'`);
        // TODO: proper error handling
        try {
            const res = await (0, node_fetch_1.default)(url, {
                method: 'POST',
                body: JSON.stringify({
                    callbackType: 'event',
                    eventType: 'peerconnection-status-changed',
                    peerconnection: await peerconnection_1.peerconnectionRepository.format(peerconnection),
                }),
                headers: [['Content-Type', 'application/json']],
            });
            if (res.status === 410) {
                const statusCallbackURLs = exports.statusChangedCallbacks.get(peerconnection.uuid);
                exports.statusChangedCallbacks.set(peerconnection.uuid, statusCallbackURLs?.filter((cb_url) => cb_url != url));
            }
        }
        catch (error) {
            console.error(error);
        }
    }
}
exports.sendStatusChangedCallback = sendStatusChangedCallback;
//# sourceMappingURL=callbacks.js.map