"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.signalingQueue = void 0;
const peerconnection_1 = require("../database/repositories/peerconnection");
const globals_1 = require("../globals");
const urlFromId_1 = require("./urlFromId");
const queue_1 = __importDefault(require("queue"));
class SignalingQueue {
    constructor() {
        this.queue = new queue_1.default({
            autostart: true,
            concurrency: 1,
        });
    }
    addPeerconnection(peerconnection) {
        this.queue.push(async function () {
            try {
                await startSignaling(peerconnection.uuid);
            }
            catch (error) {
                console.error(error);
            }
        });
    }
    isEmpty() {
        return this.queue.length === 0;
    }
}
exports.signalingQueue = new SignalingQueue();
/**
 * This function starts the signaling process for a peerconnection.
 * @param peerconnection The peerconnection the signaling process should be started for.
 * @throws Throws errors of the {@link apiClient.sendSignalingMessage | sendSignalingMessage()} function of the api-client.
 */
async function startSignaling(peerconnectionId) {
    console.log(`Starting signaling for ${peerconnectionId}`);
    const peerconnectionModel = await peerconnection_1.peerconnectionRepository.findOneOrFail({
        where: {
            uuid: peerconnectionId,
        },
        // relations: {
        //     deviceA: {
        //         config: true,
        //     },
        //     deviceB: {
        //         config: true,
        //     },
        // },
    });
    if (peerconnectionModel.status !== 'new') {
        console.log(`status of peerconnection '${(0, urlFromId_1.peerconnectionUrlFromId)(peerconnectionModel.uuid)}' is not 'new', '${peerconnectionModel.status}'`);
        return;
    }
    const common = {
        messageType: 'command',
        command: 'createPeerconnection',
        connectionType: peerconnectionModel.type,
        connectionUrl: (0, urlFromId_1.peerconnectionUrlFromId)(peerconnectionModel.uuid),
    };
    const createPeerConnectionMessageA = {
        ...common,
        services: peerconnectionModel.deviceA.config?.services ?? [],
        tiebreaker: false,
    };
    const createPeerConnectionMessageB = {
        ...common,
        services: peerconnectionModel.deviceB.config?.services ?? [],
        tiebreaker: true,
    };
    // TODO: find out how to handle the different possible errors
    peerconnectionModel.status = 'connecting';
    await peerconnection_1.peerconnectionRepository.save(peerconnectionModel);
    await globals_1.apiClient.sendSignalingMessage(peerconnectionModel.deviceA.url, createPeerConnectionMessageA, (0, urlFromId_1.peerconnectionUrlFromId)(peerconnectionModel.uuid));
    await globals_1.apiClient.sendSignalingMessage(peerconnectionModel.deviceB.url, createPeerConnectionMessageB, (0, urlFromId_1.peerconnectionUrlFromId)(peerconnectionModel.uuid));
}
//# sourceMappingURL=signaling.js.map