"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleEventCallback = void 0;
const deviceChanged_1 = require("./deviceChanged");
const service_common_1 = require("@crosslab/service-common");
/**
 * This function handles an incoming event callback.
 * @param callback The incoming event callback to be handled.
 * @throws {MalformedBodyError} Thrown if the callback is malformed.
 * @throws {InvalidValueError} Thrown if the type of the event callback is unknown.
 * @returns The status code of the callback response.
 */
async function handleEventCallback(callback) {
    if (!callback.eventType) {
        throw new service_common_1.MalformedBodyError("Callbacks of type 'event' require property 'eventType'", 400);
    }
    if (typeof callback.eventType !== 'string') {
        throw new service_common_1.MalformedBodyError("Property 'eventType' needs to be of type 'string'", 400);
    }
    switch (callback.eventType) {
        case 'device-changed':
            return await (0, deviceChanged_1.handleDeviceChangedEventCallback)(callback);
        default:
            throw new service_common_1.InvalidValueError(`Event-callbacks of type '${callback.eventType}' are not supported`, 400);
    }
}
exports.handleEventCallback = handleEventCallback;
//# sourceMappingURL=index.js.map