"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postDevicesByDeviceIdAvailability = void 0;
const device_1 = require("../../../../database/repositories/device");
const availability_1 = require("../../../../methods/availability");
const callbacks_1 = require("../../../../methods/callbacks");
const service_common_1 = require("@crosslab/service-common");
const YEAR = 365 * 24 * 60 * 60 * 1000;
/**
 * This function implements the functionality for handling POST requests on /devices/{device_id}/availability endpoint.
 * @param parameters The parameters of the request.
 * @param body The body of the request.
 * @param _user The user submitting the request.
 * @throws {MissingEntityError} Thrown if device is not found in the database.
 */
const postDevicesByDeviceIdAvailability = async (parameters, body, _user) => {
    console.log(`postDevicesByDeviceIdAvailability called`);
    const deviceModel = await device_1.deviceRepository.findOneOrFail({
        where: { uuid: parameters.device_id },
    });
    if (deviceModel.type !== 'device') {
        throw new service_common_1.ImpossibleOperationError(`Can only update the availability for a device of type 'device', not for type '${deviceModel.type}'`, 400);
    }
    deviceModel.availabilityRules ??= [];
    deviceModel.availabilityRules.push(...(body ?? []));
    const start = Date.now();
    const end = start + YEAR;
    deviceModel.announcedAvailability = (0, availability_1.calculateAvailability)(deviceModel.availabilityRules, start, end);
    await device_1.deviceRepository.save(deviceModel);
    await (0, callbacks_1.sendChangedCallback)(deviceModel);
    console.log(`postDevicesByDeviceIdAvailability succeeded`);
    return {
        status: 200,
        body: deviceModel.announcedAvailability,
    };
};
exports.postDevicesByDeviceIdAvailability = postDevicesByDeviceIdAvailability;
//# sourceMappingURL=post.js.map