"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.patchDevicesByDeviceId = void 0;
const device_1 = require("../../../database/repositories/device");
const callbacks_1 = require("../../../methods/callbacks");
const urlFromId_1 = require("../../../methods/urlFromId");
/**
 * This function implements the functionality for handling PATCH requests on /devices/{device_id} endpoint.
 * @param parameters The parameters of the request.
 * @param body The body of the request.
 * @param _user The user submitting the request.
 * @throws {MissingEntityError} Thrown if device is not found in the database.
 * @throws {InvalidChangeError} Thrown if client tries to update the type of the device.
 */
const patchDevicesByDeviceId = async (parameters, body, _user) => {
    console.log(`patchDevicesByDeviceId called`);
    const deviceModel = await device_1.deviceRepository.findOneOrFail({
        where: { uuid: parameters.device_id },
    });
    await device_1.deviceRepository.write(deviceModel, body ?? { type: deviceModel.type });
    await device_1.deviceRepository.save(deviceModel);
    await (0, callbacks_1.sendChangedCallback)(deviceModel);
    if (parameters.changedUrl) {
        console.log(`registering changed-callback for device '${(0, urlFromId_1.deviceUrlFromId)(deviceModel.uuid)}' to '${parameters.changedUrl}'`);
        const changedCallbackURLs = callbacks_1.changedCallbacks.get(deviceModel.uuid) ?? [];
        changedCallbackURLs.push(parameters.changedUrl);
        callbacks_1.changedCallbacks.set(deviceModel.uuid, changedCallbackURLs);
    }
    console.log(`patchDevicesByDeviceId succeeded`);
    return {
        status: 200,
        body: await device_1.deviceRepository.format(deviceModel),
    };
};
exports.patchDevicesByDeviceId = patchDevicesByDeviceId;
//# sourceMappingURL=patch.js.map