"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postDevicesByDeviceIdWebsocket = void 0;
const device_1 = require("../../../../database/repositories/device");
const service_common_1 = require("@crosslab/service-common");
const crypto_1 = require("crypto");
/**
 * This function implements the functionality for handling POST requests on /devices/{device_id}/token endpoint.
 * @param parameters The parameters of the request.
 * @param _user The user submitting the request.
 * @throws {_MissingEntityError} Thrown if device is not found in the database.
 */
const postDevicesByDeviceIdWebsocket = async (parameters, _user) => {
    console.log(`postDevicesByDeviceIdWebsocket called`);
    const deviceModel = await device_1.deviceRepository.findOneOrFail({
        where: {
            uuid: parameters.device_id,
        },
    });
    if (deviceModel.type !== 'device')
        throw new service_common_1.ImpossibleOperationError("A websocket token may only be requested for a device of type 'device'", 400);
    deviceModel.token = (0, crypto_1.randomUUID)();
    await device_1.deviceRepository.save(deviceModel);
    setTimeout(async () => {
        deviceModel.token = undefined;
        await device_1.deviceRepository.save(deviceModel);
    }, 300000);
    console.log(`postDevicesByDeviceIdWebsocket succeeded`);
    return {
        status: 200,
        body: deviceModel.token,
    };
};
exports.postDevicesByDeviceIdWebsocket = postDevicesByDeviceIdWebsocket;
//# sourceMappingURL=post.js.map