"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleDeviceMessage = void 0;
const types_1 = require("../../../generated/types");
const globals_1 = require("../../../globals");
const urlFromId_1 = require("../../../methods/urlFromId");
const service_common_1 = require("@crosslab/service-common");
/**
 * This function handles a message for a device.
 * @param deviceModel The device for which to handle the message.
 * @param message The message to be handled.
 */
async function handleDeviceMessage(deviceModel, message) {
    if ((0, types_1.isSignalingMessage)(message)) {
        await handleSignalingMessage(deviceModel, message);
    }
    else if ((0, types_1.isConnectionStateChangedMessage)(message)) {
        await handleConnectionStateChangedMessage(deviceModel, message);
    }
}
exports.handleDeviceMessage = handleDeviceMessage;
/**
 * This function handles a signaling message for a device.
 * @param deviceModel The device for which to handle the signaling message.
 * @param message The signaling message to be handled.
 */
async function handleSignalingMessage(deviceModel, message) {
    const peerconnection = await globals_1.apiClient.getPeerconnection(message.connectionUrl);
    const deviceA = peerconnection.devices[0];
    const deviceB = peerconnection.devices[1];
    let peerDeviceUrl = undefined;
    if (deviceA.url === (0, urlFromId_1.deviceUrlFromId)(deviceModel.uuid))
        peerDeviceUrl = deviceB.url;
    if (deviceB.url === (0, urlFromId_1.deviceUrlFromId)(deviceModel.uuid))
        peerDeviceUrl = deviceA.url;
    if (!peerDeviceUrl) {
        throw new service_common_1.UnrelatedPeerconnectionError('Device is not taking part in peerconnection.', 400);
    }
    await globals_1.apiClient.sendSignalingMessage(peerDeviceUrl, message, message.connectionUrl);
}
/**
 * This function handles a connection-state-changed message for a device.
 * @param deviceModel The device for which the connection state changed
 * @param message The connection-state-changed message.
 */
async function handleConnectionStateChangedMessage(deviceModel, message) {
    await globals_1.apiClient.patchPeerconnectionDeviceStatus(message.connectionUrl, { status: message.status }, (0, urlFromId_1.deviceUrlFromId)(deviceModel.uuid));
}
//# sourceMappingURL=messageHandling.js.map