"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deletePeerconnectionsByPeerconnectionId = void 0;
const peerconnection_1 = require("../../../database/repositories/peerconnection");
const globals_1 = require("../../../globals");
const callbacks_1 = require("../../../methods/callbacks");
const urlFromId_1 = require("../../../methods/urlFromId");
/**
 * This function implements the functionality for handling DELETE requests on /peerconnection/{peerconnection_id} endpoint.
 * @param parameters The parameters of the request.
 * @param _user The user submitting the request.
 */
const deletePeerconnectionsByPeerconnectionId = async (parameters, _user) => {
    console.log(`deletePeerconnectionsByPeerconnectionId called`);
    const peerconnectionModel = await peerconnection_1.peerconnectionRepository.findOneOrFail({
        where: { uuid: parameters.peerconnection_id },
    });
    const closePeerconnectionMessage = {
        messageType: 'command',
        command: 'closePeerconnection',
        connectionUrl: (0, urlFromId_1.peerconnectionUrlFromId)(peerconnectionModel.uuid),
    };
    // TODO: handle possible errors
    try {
        await globals_1.apiClient.sendSignalingMessage(peerconnectionModel.deviceA.url, closePeerconnectionMessage, (0, urlFromId_1.peerconnectionUrlFromId)(peerconnectionModel.uuid));
    }
    catch (error) {
        console.error(error);
    }
    try {
        await globals_1.apiClient.sendSignalingMessage(peerconnectionModel.deviceB.url, closePeerconnectionMessage, (0, urlFromId_1.peerconnectionUrlFromId)(peerconnectionModel.uuid));
    }
    catch (error) {
        console.error(error);
    }
    await (0, callbacks_1.sendClosedCallback)(peerconnectionModel);
    await (0, callbacks_1.sendStatusChangedCallback)(peerconnectionModel);
    await peerconnection_1.peerconnectionRepository.remove(peerconnectionModel);
    console.log(`deletePeerconnectionsByPeerconnectionId succeeded`);
    return {
        status: 204,
    };
};
exports.deletePeerconnectionsByPeerconnectionId = deletePeerconnectionsByPeerconnectionId;
//# sourceMappingURL=delete.js.map