"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.patchPeerconnectionsByPeerconnectionIdDeviceStatus = void 0;
const peerconnection_1 = require("../../../../database/repositories/peerconnection");
const urlFromId_1 = require("../../../../methods/urlFromId");
const callbacks_1 = require("../../../callbacks");
const service_common_1 = require("@crosslab/service-common");
/**
 * This function implements the functionality for handling GET requests on /peerconnections/{peerconnection_id} endpoint.
 * @param parameters The parameters of the request.
 * @param _user The user submitting the request.
 */
const patchPeerconnectionsByPeerconnectionIdDeviceStatus = async (parameters, body, _user) => {
    console.log(`patchPeerconnectionsByPeerconnectionIdDeviceStatus called`);
    const peerconnectionModel = await peerconnection_1.peerconnectionRepository.findOneOrFail({
        where: { uuid: parameters.peerconnection_id },
    });
    if (peerconnectionModel.deviceA.url !== parameters.device_url &&
        peerconnectionModel.deviceB.url !== parameters.device_url) {
        throw new service_common_1.UnrelatedPeerconnectionError(`Device '${parameters.device_url}' is not taking part in peerconnection '${(0, urlFromId_1.peerconnectionUrlFromId)(peerconnectionModel.uuid)}'`, 400);
    }
    if (peerconnectionModel.deviceA.url === parameters.device_url)
        peerconnectionModel.deviceA.status = body.status;
    if (peerconnectionModel.deviceB.url === parameters.device_url)
        peerconnectionModel.deviceB.status = body.status;
    const oldStatus = peerconnectionModel.status;
    if (peerconnectionModel.status === 'closed' ||
        peerconnectionModel.deviceA.status === 'closed' ||
        peerconnectionModel.deviceB.status === 'closed') {
        peerconnectionModel.status = 'closed';
    }
    else if (peerconnectionModel.deviceA.status === 'failed' ||
        peerconnectionModel.deviceB.status === 'failed') {
        peerconnectionModel.status = 'failed';
    }
    else if (peerconnectionModel.deviceA.status === 'disconnected' ||
        peerconnectionModel.deviceB.status === 'disconnected') {
        peerconnectionModel.status = 'disconnected';
    }
    else if (peerconnectionModel.deviceA.status === 'connecting' ||
        peerconnectionModel.deviceB.status === 'connecting') {
        peerconnectionModel.status = 'connecting';
    }
    else if (peerconnectionModel.deviceA.status === 'connected' &&
        peerconnectionModel.deviceB.status === 'connected') {
        peerconnectionModel.status = 'connected';
    }
    else {
        peerconnectionModel.status = 'new';
    }
    if (peerconnectionModel.status !== oldStatus)
        await (0, callbacks_1.sendStatusChangedCallback)(peerconnectionModel);
    await peerconnection_1.peerconnectionRepository.save(peerconnectionModel);
    console.log(`patchPeerconnectionsByPeerconnectionIdDeviceStatus succeeded`);
    return {
        status: 201,
    };
};
exports.patchPeerconnectionsByPeerconnectionIdDeviceStatus = patchPeerconnectionsByPeerconnectionIdDeviceStatus;
//# sourceMappingURL=patch.js.map